remove some unused stuff
[project/uci.git] / uci.h
diff --git a/uci.h b/uci.h
index 8e73bfe..ac85105 100644 (file)
--- a/uci.h
+++ b/uci.h
@@ -63,6 +63,7 @@ struct uci_section;
 struct uci_option;
 struct uci_history;
 struct uci_context;
+struct uci_backend;
 struct uci_parse_context;
 
 
@@ -136,13 +137,6 @@ extern int uci_load(struct uci_context *ctx, const char *name, struct uci_packag
 extern int uci_unload(struct uci_context *ctx, struct uci_package *p);
 
 /**
- * uci_cleanup: Clean up after an error
- *
- * @ctx: uci context
- */
-extern int uci_cleanup(struct uci_context *ctx);
-
-/**
  * uci_lookup: Look up an uci element
  *
  * @ctx: uci context
@@ -157,6 +151,15 @@ extern int uci_cleanup(struct uci_context *ctx);
 extern int uci_lookup(struct uci_context *ctx, struct uci_element **res, struct uci_package *package, char *section, char *option);
 
 /**
+ * uci_add_section: Add an unnamed section
+ * @ctx: uci context
+ * @p: package to add the section to
+ * @type: section type
+ * @res: pointer to store a reference to the new section in
+ */
+extern int uci_add_section(struct uci_context *ctx, struct uci_package *p, char *type, struct uci_section **res);
+
+/**
  * uci_set_element_value: Replace an element's value with a new one
  * @ctx: uci context
  * @element: pointer to an uci_element struct pointer
@@ -174,8 +177,9 @@ extern int uci_set_element_value(struct uci_context *ctx, struct uci_element **e
  * @section: section name
  * @option: option name
  * @value: value (option) or type (section)
+ * @result: store the updated element in this variable (optional)
  */
-extern int uci_set(struct uci_context *ctx, struct uci_package *p, char *section, char *option, char *value);
+extern int uci_set(struct uci_context *ctx, struct uci_package *p, char *section, char *option, char *value, struct uci_element **result);
 
 /**
  * uci_rename: Rename an element
@@ -224,6 +228,8 @@ extern int uci_commit(struct uci_context *ctx, struct uci_package **p, bool over
 /**
  * uci_list_configs: List available uci config files
  * @ctx: uci context
+ *
+ * caller is responsible for freeing the allocated memory behind list
  */
 extern int uci_list_configs(struct uci_context *ctx, char ***list);
 
@@ -260,6 +266,15 @@ extern int uci_add_history_path(struct uci_context *ctx, const char *dir);
  */
 extern int uci_revert(struct uci_context *ctx, struct uci_package **p, char *section, char *option);
 
+/**
+ * uci_parse_argument: parse a shell-style argument, with an arbitrary quoting style
+ * @ctx: uci context
+ * @stream: input stream
+ * @str: pointer to the current line (use NULL for parsing the next line)
+ * @result: pointer for the result
+ */
+extern int uci_parse_argument(struct uci_context *ctx, FILE *stream, char **str, char **result);
+
 /* UCI data structures */
 enum uci_type {
        UCI_TYPE_HISTORY = 0,
@@ -270,9 +285,10 @@ enum uci_type {
 };
 
 enum uci_flags {
-       UCI_FLAG_STRICT =      (1 << 0), /* strict mode for the parser */
-       UCI_FLAG_PERROR =      (1 << 1), /* print parser error messages */
-       UCI_FLAG_EXPORT_NAME = (1 << 2), /* when exporting, name unnamed sections */
+       UCI_FLAG_STRICT =        (1 << 0), /* strict mode for the parser */
+       UCI_FLAG_PERROR =        (1 << 1), /* print parser error messages */
+       UCI_FLAG_EXPORT_NAME =   (1 << 2), /* when exporting, name unnamed sections */
+       UCI_FLAG_SAVED_HISTORY = (1 << 3), /* store the saved history in memory as well */
 };
 
 struct uci_element
@@ -282,6 +298,15 @@ struct uci_element
        char *name;
 };
 
+struct uci_backend
+{
+       const char *name;
+       char **(*list_configs)(struct uci_context *ctx);
+       struct uci_package *(*load)(struct uci_context *ctx, const char *name);
+       void (*commit)(struct uci_context *ctx, struct uci_package **p, bool overwrite);
+};
+
+
 struct uci_context
 {
        /* list of config packages */
@@ -290,6 +315,9 @@ struct uci_context
        /* parser context, use for error handling only */
        struct uci_parse_context *pctx;
 
+       /* backend for import and export */
+       struct uci_backend *backend;
+
        /* uci runtime flags */
        enum uci_flags flags;
 
@@ -308,34 +336,19 @@ struct uci_context
        int bufsz;
 };
 
-struct uci_parse_context
-{
-       /* error context */
-       const char *reason;
-       int line;
-       int byte;
-
-       /* private: */
-       struct uci_package *package;
-       struct uci_section *section;
-       bool merge;
-       FILE *file;
-       const char *name;
-       char *buf;
-       int bufsz;
-};
-
 struct uci_package
 {
        struct uci_element e;
        struct uci_list sections;
        struct uci_context *ctx;
-       bool confdir;
+       bool has_history;
        char *path;
 
        /* private: */
+       struct uci_backend *backend;
        int n_section;
        struct uci_list history;
+       struct uci_list saved_history;
 };
 
 struct uci_section
@@ -389,9 +402,6 @@ struct uci_history
  * @_type: config, section or option
  * @_ptr: pointer to the uci_list struct
  */
-#define element_to(type, ptr) \
-       container_of(ptr, struct uci_ ## type, e)
-
 #define list_to_element(ptr) \
        container_of(ptr, struct uci_element, list)